

#ifndef _Waypoint_H__
#define _Waypoint_H__

#include "OrxonoxPrereqs.h"
#include "Waypointprereqs.h"
#include "worldentities/StaticEntity.h"
#include "graphics/Model.h"
#include "objects/triggers/DistanceTrigger.h"

#include <map>
#include <string>

#include "util/OgreForwardRefs.h"
#include "tools/interfaces/Tickable.h"
#include "WaypointGroup.h"


namespace orxonox
{
    /**
    @brief
        The StaticEntity is the simplest derivative of the @ref orxonox::WorldEntity class. This means all StaticEntity instances also have
        a position in space, a mass, a scale, a frication, ... because every StaticEntity is a WorldEntity. You can attach StaticEntities to eachother ike @ref orxonox::WorldEntity WorldEntities.

        In contrast to the MobileEntity the StaticEntity cannot move with respect to the parent to which it is attached. That's why
        it is called StaticEntity. It will keep the same position (always with respect to its parent) forever unless you call the
        function @see setPosition to changee it.

        A StaticEntity can only have the collisition type WorldEntity::None or WorldEntity::Static. The collsion types WorldEntity::Dynamic and WorldEntity::Kinematic are illegal.
    */

    class _OrxonoxExport Waypoint : public StaticEntity {
        
        public:

            Waypoint(Context* context);
            virtual ~Waypoint();


            virtual void XMLEventPort(Element& xmlelement, XMLPort::Mode mode) override;

            inline void enable_waypoint(){
                this->waypoint_actived = true;
            }

            inline void setOrder(int number){
                this->order = number;
            }

            inline int getOrder(){
                return this->order;
            }

            inline void setWaypointGroup(WaypointGroup* waypointgroup_){
                this->waypointgroup = waypointgroup_;
            }

            void activate();

            
            bool waypoint_actived;

        private:
    
            //virtual bool isCollisionTypeLegal(CollisionType type) const override;
            Model* model;
            DistanceTrigger* distancetrigger;
            unsigned int order = 0;
            WaypointGroup* waypointgroup;

            // network callbacks
    };
}

#endif /* _Waypoint_H__ */
